Package: scpdata
Type: Package
Title: Single-Cell Proteomics Data Package
Version: 1.21.2
Authors@R: 
    c(person("Christophe", "Vanderaa",
              email = "vanderaa.christophe@gmail.com",
              comment = c(ORCID = "0000-0001-7443-5427"),
              role = c("aut", "cre")),
      person("Laurent", "Gatto",
              email = "laurent.gatto@uclouvain.be",
              comment = c(ORCID = "0000-0002-1520-2268"),
              role = "aut"),
      person("Enes", "Ayar",
              email = "enes.ayar@uclouvain.be",
              comment = c(ORCID = "0000-0001-8881-9800"),
              role = "dtc"),
      person("Samuel", "Grégoire",
              email = "samuel.gregoire@uclouvain.be",
              comment = c(ORCID = "0000-0002-0900-7677"),
              role = "dtc"))
Description: The package disseminates mass spectrometry (MS)-based
    single-cell proteomics (SCP) datasets. The data were collected
    from published work and formatted using the `scp` data structure.
    The data sets contain quantitative information at spectrum,
    peptide and/or protein level for single cells or minute sample
    amounts.
Depends: R (>= 4.2.0), QFeatures, ExperimentHub
Imports: utils, AnnotationHub, SingleCellExperiment, S4Vectors
Suggests: scp, magrittr, dplyr, knitr, BiocStyle, BiocCheck, rmarkdown,
        testthat
biocViews: ExperimentData, ExpressionData, ExperimentHub,
        ReproducibleResearch, MassSpectrometryData, Proteome,
        SingleCellData, PackageTypeData
License: GPL-3
Encoding: UTF-8
VignetteBuilder: knitr
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
git_url: https://git.bioconductor.org/packages/scpdata
git_branch: devel
git_last_commit: c2d8a76
git_last_commit_date: 2026-08-27
Repository: Bioconductor 3.24
Date/Publication: 2026-08-27
NeedsCompilation: no
Packaged: 2026-08-27 15:37:04 UTC; biocbuild
Author: Christophe Vanderaa [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7443-5427>),
  Laurent Gatto [aut] (ORCID: <https://orcid.org/0000-0002-1520-2268>),
  Enes Ayar [dtc] (ORCID: <https://orcid.org/0000-0001-8881-9800>),
  Samuel Grégoire [dtc] (ORCID: <https://orcid.org/0000-0002-0900-7677>)
Maintainer: Christophe Vanderaa <vanderaa.christophe@gmail.com>
