# Generated by roxygen2: do not edit by hand

export(leduc2022)
export(scpdata)
import(ExperimentHub)
import(QFeatures)
import(SingleCellExperiment)
importFrom(AnnotationHub,query)
importFrom(S4Vectors,mcols)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
